@@ -1,25 +1,34 @@
 """Helper methods for libtmux and downstream libtmux libraries."""
 
+from __future__ import annotations
+
 import contextlib
 import logging
 import os
 import pathlib
 import random
 import time
-import types
 import typing as t
-from typing import Callable, Optional
-
-from libtmux.server import Server
 
 from .exc import WaitTimeout
 
 logger = logging.getLogger(__name__)
 
 if t.TYPE_CHECKING:
+    import sys
+    import types
+    from collections.abc import Callable, Generator
+
+    from libtmux.server import Server
     from libtmux.session import Session
     from libtmux.window import Window
 
+    if sys.version_info >= (3, 11):
+        from typing import Self
+    else:
+        from typing_extensions import Self
+
+
 TEST_SESSION_PREFIX = "libtmux_"
 RETRY_TIMEOUT_SECONDS = int(os.getenv("RETRY_TIMEOUT_SECONDS", 8))
 RETRY_INTERVAL_SECONDS = float(os.getenv("RETRY_INTERVAL_SECONDS", 0.05))
@@ -44,7 +53,7 @@ class RandomStrSequence:
         """
         self.characters: str = characters
 
-    def __iter__(self) -> "RandomStrSequence":
+    def __iter__(self) -> RandomStrSequence:
         """Return self."""
         return self
 
@@ -64,7 +73,7 @@ def retry_until(
     seconds: float = RETRY_TIMEOUT_SECONDS,
     *,
     interval: float = RETRY_INTERVAL_SECONDS,
-    raises: Optional[bool] = True,
+    raises: bool | None = True,
 ) -> bool:
     """
     Retry a function until a condition meets or the specified time passes.
@@ -102,14 +111,13 @@ def retry_until(
         end = time.time()
         if end - ini >= seconds:
             if raises:
-                raise WaitTimeout()
-            else:
-                return False
+                raise WaitTimeout
+            return False
         time.sleep(interval)
     return True
 
 
-def get_test_session_name(server: "Server", prefix: str = TEST_SESSION_PREFIX) -> str:
+def get_test_session_name(server: Server, prefix: str = TEST_SESSION_PREFIX) -> str:
     """
     Faker to create a session name that doesn't exist.
 
@@ -143,8 +151,8 @@ def get_test_session_name(server: "Server", prefix: str = TEST_SESSION_PREFIX) -
 
 
 def get_test_window_name(
-    session: "Session",
-    prefix: t.Optional[str] = TEST_SESSION_PREFIX,
+    session: Session,
+    prefix: str | None = TEST_SESSION_PREFIX,
 ) -> str:
     """
     Faker to create a window name that doesn't exist.
@@ -186,7 +194,7 @@ def temp_session(
     server: Server,
     *args: t.Any,
     **kwargs: t.Any,
-) -> t.Generator["Session", t.Any, t.Any]:
+) -> Generator[Session, t.Any, t.Any]:
     """
     Return a context manager with a temporary session.
 
@@ -234,10 +242,10 @@ def temp_session(
 
 @contextlib.contextmanager
 def temp_window(
-    session: "Session",
+    session: Session,
     *args: t.Any,
     **kwargs: t.Any,
-) -> t.Generator["Window", t.Any, t.Any]:
+) -> Generator[Window, t.Any, t.Any]:
     """
     Return a context manager with a temporary window.
 
@@ -271,7 +279,7 @@ def temp_window(
 
 
     >>> with temp_window(session) as window:
-    ...     window.split_window()
+    ...     window.split()
     Pane(%4 Window(@3 2:libtmux_..., Session($1 libtmux_...)))
     """
     if "window_name" not in kwargs:
@@ -314,8 +322,8 @@ class EnvironmentVarGuard:
 
     def __init__(self) -> None:
         self._environ = os.environ
-        self._unset: t.Set[str] = set()
-        self._reset: t.Dict[str, str] = {}
+        self._unset: set[str] = set()
+        self._reset: dict[str, str] = {}
 
     def set(self, envvar: str, value: str) -> None:
         """Set environment variable."""
@@ -331,15 +339,15 @@ class EnvironmentVarGuard:
             self._reset[envvar] = self._environ[envvar]
             del self._environ[envvar]
 
-    def __enter__(self) -> "EnvironmentVarGuard":
+    def __enter__(self) -> Self:
         """Return context for for context manager."""
         return self
 
     def __exit__(
         self,
-        exc_type: t.Union[t.Type[BaseException], None],
-        exc_value: t.Optional[BaseException],
-        exc_tb: t.Optional[types.TracebackType],
+        exc_type: type[BaseException] | None,
+        exc_value: BaseException | None,
+        exc_tb: types.TracebackType | None,
     ) -> None:
         """Cleanup to run after context manager finishes."""
         for envvar, value in self._reset.items():
